@@ -8,25 +8,27 @@ from trapperkeeper.models import Notification
 class Index(TrapdoorHandler):
     def get(self):
 
-        now = datetime.now()
+        now = datetime.utcnow()
         offset = int(self.get_argument("offset", 0))
         limit = int(self.get_argument("limit", 50))
+        hostname = self.get_argument("hostname", None)
+        oid = self.get_argument("oid", None)
 
         active_query = (self.db
-            .query(
-                Notification.id,
-                Notification.host,
-                Notification.oid,
-                Notification.sent,
-                func.max(Notification.expires).label("expires"))
+            .query(Notification)
             .filter(or_(
                 Notification.expires >= now,
                 Notification.expires == None
              ))
-            .group_by(Notification.host, Notification.oid)
             .order_by(desc(Notification.sent))
         )
 
+        if hostname is not None:
+            active_query = active_query.filter(Notification.host == hostname)
+
+        if oid is not None:
+            active_query = active_query.filter(Notification.oid == oid)
+
         total_active = active_query.count()
         traps = active_query.offset(offset).limit(limit).all()
         num_active = len(traps)
@@ -39,20 +41,23 @@ class Index(TrapdoorHandler):
                 remaining_offset = 0
 
         if num_active < limit:
-            traps += (self.db
-                .query(
-                    Notification.id,
-                    Notification.host,
-                    Notification.oid,
-                    Notification.sent,
-                    Notification.expires)
+            expired_query = (self.db
+                .query(Notification)
                 .filter(Notification.expires < now)
                 .order_by(desc(Notification.sent))
-                .offset(remaining_offset)
-                .limit(limit - num_active)
-                .all()
             )
-        return self.render("index.html", traps=traps, now=now, num_active=num_active, limit=limit)
+
+            if hostname is not None:
+                expired_query = expired_query.filter(Notification.host == hostname)
+
+            if oid is not None:
+                expired_query = expired_query.filter(Notification.oid == oid)
+
+            traps += expired_query.offset(remaining_offset).limit(limit - num_active).all()
+
+        return self.render(
+            "index.html", traps=traps, now=now, num_active=num_active,
+            hostname=hostname, oid=oid, offset=offset, limit=limit)
 
 class Traps(TrapdoorHandler):
     def get(self):
@@ -64,7 +69,7 @@ class Resolve(TrapdoorHandler):
         hostname = self.get_argument("host")
         oid = self.get_argument("oid")
 
-        now = datetime.now()
+        now = datetime.utcnow()
 
         traps = (self.db.query(Notification)
             .filter(
@@ -87,7 +92,7 @@ class Resolve(TrapdoorHandler):
 class ResolveAll(TrapdoorHandler):
     def post(self):
 
-        now = datetime.now()
+        now = datetime.utcnow()
         traps = (self.db.query(Notification)
             .filter(
                 or_(
