@@ -1,4 +1,6 @@
+import pytz
 import tornado.web
+import urllib
 
 class TrapdoorHandler(tornado.web.RequestHandler):
 
@@ -23,13 +25,26 @@ class TrapdoorHandler(tornado.web.RequestHandler):
         self.set_status(404)
         self.render("errors/notfound.html")
 
-
+# TODO(gary): Make timezone configurable.
+LOCALTZ = pytz.timezone('America/Los_Angeles')
 def print_date(date_obj):
     if date_obj is None:
         return ""
+
+    date_obj = date_obj.astimezone(LOCALTZ)
     return date_obj.strftime("%Y-%m-%d %I:%M %p")
 
 
-FILTERS = {
+jinja2_filters = {
     "print_date": print_date,
 }
+
+
+def update_qs(qs, **kwargs):
+    qs = qs.copy()
+    qs.update(kwargs)
+    return "?" + urllib.urlencode(qs, True)
+
+jinja2_globals = {
+    "update_qs": update_qs,
+}
